#
# spec file for package kf6-kuserfeedback
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.8.0

%define rname kuserfeedback

# Full KF6 version (e.g. 6.16.0)
%{!?_kf6_version: %global _kf6_version %{version}}
%bcond_without released
Name:           kf6-kuserfeedback
Version:        6.16.0
Release:        1.1
Summary:        Framework for collecting feedback from application users
License:        MIT
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  bison
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_version}
BuildRequires:  flex
BuildRequires:  fdupes
# # Needed for tests
BuildRequires:  Mesa-dri
BuildRequires:  xvfb-run
BuildRequires:  cmake(Qt6Charts) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}

%description
KUserFeedback is a framework which allows applications to collect user
telemetry and feedback surveys. It is designed to be compliant with the
KDE Telemetry Policy, which forbids the usage of unique identification.

%package -n libKF6UserFeedbackCore6
Summary:        Framework for collecting feedback from application users
Requires:       kf6-kuserfeedback >= %{version}
Recommends:     kf6-kuserfeedback-imports
Recommends:     kf6-kuserfeedback-lang
Recommends:     libKF6UserFeedbackWidgets6

%description -n libKF6UserFeedbackCore6
KUserFeedback is a framework which allows applications to collect user
telemetry and feedback surveys. It is designed to be compliant with the
KDE Telemetry Policy, which forbids the usage of unique identification.

%package -n libKF6UserFeedbackWidgets6
Summary:        User interface components for kf6-kuserfeedback
Requires:       kf6-kuserfeedback >= %{version}

%description -n libKF6UserFeedbackWidgets6
KUserFeedback is a framework which allows applications to collect user
telemetry and feedback surveys. This package provides the user interface
components to integrate the framework in Qt applications.

%package imports
Summary:        QML interface components for kf6-kuserfeedback
Requires:       kf6-kuserfeedback >= %{version}
Requires:       libKF6UserFeedbackCore6 = %{version}
Requires:       libKF6UserFeedbackWidgets6 = %{version}

%description imports
KUserFeedback is a framework which allows applications to collect user
telemetry and feedback surveys. This package provides the QtQuick components
needed to build QML interfaces leveraging the library.

%package server
Summary:        Server component of kf6-kuserfeedback
Requires:       (php-sqlite or php-mysql or php-pgsql)
Requires:       kf6-kuserfeedback >= %{version}
Requires:       php
Conflicts:      kuserfeedback-server

%description server
KUserFeedback is a framework which allows applications to collect user
telemetry and feedback surveys. This package provides a server component
used to collect telemetry and feedback.

%package devel
Summary:        Development files for kf6-kuserfeedback
Requires:       kf6-kuserfeedback >= %{version}
Requires:       libKF6UserFeedbackCore6 = %{version}
Requires:       libKF6UserFeedbackWidgets6 = %{version}
Conflicts:      kuserfeedback-devel

%description devel
Development files for kf6-kuserfeedback, a framework for collecting feedback from
application users via telemetry and targeted surveys.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
# FIXME Docs use a hardcoded path in the application code
# Disable until fixed upstream
%cmake_kf6 \
  -DQT_MAJOR_VERSION:STRING=6 \
  -DENABLE_DOCS:BOOL=FALSE \
  -DBUILD_TESTING:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-qt --all-name

mkdir -p %{buildroot}%{_kf6_sharedir}/php/
cp -r src/server %{buildroot}%{_kf6_sharedir}/php/kuserfeedback6
# CMakeLists.txt is not needed there and will trigger a rpmlint warning
rm %{buildroot}%{_kf6_sharedir}/php/kuserfeedback6/CMakeLists.txt

%fdupes %{buildroot}

%check
pushd %__kf6_builddir
xvfb-run -s '-noreset +render' \
  ctest \
  --output-on-failure \
  --force-new-ctest-process \
  --parallel %{_smp_build_ncpus}
popd

%ldconfig_scriptlets -n libKF6UserFeedbackCore6
%ldconfig_scriptlets -n libKF6UserFeedbackWidgets6

%files
%{_kf6_debugdir}/org_kde_UserFeedback.categories

%files -n libKF6UserFeedbackCore6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6UserFeedbackCore.so.*

%files -n libKF6UserFeedbackWidgets6
%{_kf6_libdir}/libKF6UserFeedbackWidgets.so.*

%files imports
%dir %{_kf6_qmldir}/org/kde/userfeedback
%{_kf6_qmldir}/org/kde/userfeedback/

%files server
%doc composer.json
%doc INSTALL README.md
%dir %{_kf6_sharedir}/php
%{_kf6_sharedir}/php/kuserfeedback6/

%files devel
%dir %{_kf6_includedir}/KUserFeedback
%{_kf6_includedir}/KUserFeedback/kuserfeedback_version.h
%{_kf6_includedir}/KUserFeedbackCore/
%{_kf6_includedir}/KUserFeedbackWidgets/
%{_kf6_cmakedir}/KF6UserFeedback/
%{_kf6_libdir}/libKF6UserFeedbackCore.so
%{_kf6_libdir}/libKF6UserFeedbackWidgets.so
%{_kf6_mkspecsdir}/qt_KF6UserFeedbackCore.pri
%{_kf6_mkspecsdir}/qt_KF6UserFeedbackWidgets.pri

%files lang -f %{name}.lang

%changelog
* Mon Jul  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.16.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.16.0
- Changes since 6.15.0:
  * Update dependency version to 6.16.0
  * Update version to 6.16.0
* Mon Jun  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.15.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.15.0
- Changes since 6.14.0:
  * Update dependency version to 6.15.0
  * Add tags file to documentation
  * Add missing qhp projects
  * Remove leftover doxygen file
  * Add landing page for QDoc
  * Port API documentation to QDoc syntax
  * Update version to 6.15.0
- Replace _kf6_bugfix_version usage
* Sun May  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.14.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.14.0
- Changes since 6.13.0:
  * Update dependency version to 6.14.0
  * Don't build app and CLI binary by default
  * Use standard icon name: search -> system-search
  * Build CLI binary with the console app target, and vice versa
  * flatpak: Update runtime
  * Update version to 6.14.0
* Sat Apr  5 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.13.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.13.0
- Changes since 6.12.0:
  * Remove qmake info as it was removed
  * Port some code from foreach to for(...:...)
  * Update dependency version to 6.13.0
* Tue Mar 11 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.12.0
- Changes since 6.11.0:
  * Update dependency version to 6.12.0
  * Update version to 6.12.0
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Changes since 6.10.0:
  * Update dependency version to 6.11.0
  * Add xml/yaml linting
  * Use ecm_set_disabled_deprecation_versions. Next step fixing building without deprecated methods
  * CI: Add linux-qt6-next build
  * CI: Extend dependency requires to Linux/Qt6Next
  * Set desktop file name
  * Update version to 6.11.0
* Thu Jan  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * Don't include quiet packages in feature_summary
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Build master ECM as part of the Flatpak build
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * tests: allow to disable testOpenGLInfoSource using envvar
  * ci: add Alpine/musl job
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * gitignore: add VS Code dir
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * CI: Require tests to pass on Linux and FreeBSD
  * Add homepage url, CI was complaining
  * Fix target names in metainfo
  * Remove explicit maintainer from metainfo
  * Use ellipsis character instead of three dots in UI strings
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * Fix logging category
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * flatpatk: Use actual 6.6 runtime
* Tue Mar  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Move -lang conflicts to the -lang package
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kuserfeedback
